@@ -8,7 +8,7 @@ from slai_cli import log
 from slai_cli.errors import handle_error
 from slai_cli.modules.docker_client import DockerClient
 from slai_cli.modules.deployment_checks import check_handler_imports
-from slai_cli.create.local_config_helper import LocalConfigHelper
+from slai_cli.init.local_config_helper import LocalConfigHelper
 from slai_cli import constants
 
 
